@@ -2,9 +2,11 @@
 
 import io
 from base64 import b64encode, b64decode
+import concurrent.futures as cf
 import requests
 import pandas as pd
 
+
 from . import constants
 from . import proto_wrapper
 from . import errors
@@ -34,11 +36,15 @@ def _send_request(request: proto_wrapper.REQUEST) -> proto_wrapper.RESPONSE:
     try:
         res = requests.get(constants.DB_URL + 'request/v1/',
                            headers=headers, timeout=180)
+
+        if res.status_code == 502:
+            raise errors.MoabInternalError("Take2 server is down")
         if res.status_code != 200:
-            raise errors.MoabRequestError(
-                "Server returned error code: " + str(res.status_code))
+            raise errors.MoabHttpError("Unknown error")
+
         res = proto_wrapper.RESPONSE().FromString(b64decode(res.text))
         return res
+
     except requests.exceptions.Timeout as exc:
         raise errors.MoabHttpError("Unable to connect to server") from exc
 
@@ -66,9 +72,17 @@ def _server_req(ticker, start, end, datatype):
         except Exception as exc:
             raise errors.MoabResponseError(
                 "Server returned invalid data") from exc
+    elif res.code == 400:
+        raise errors.MoabRequestError("Invalid request: " + res.message)
+    elif res.code == 401:
+        raise errors.MoabUnauthorizedError("Invalid credentials")
+    elif res.code == 404:
+        raise errors.MoabNotFoundError(res.message + " not found")
+    elif res.code == 500:
+        raise errors.MoabInternalError("Server error: " + res.message)
     else:
-        raise errors.MoabRequestError(
-            "Server returned error code " + str(res.code) + ": " + res.message)
+        raise errors.MoabResponseError(
+            "Unknown error " + res.code + ": " + res.message)
 
 
 def get_equity(tickers, sample="1m",
@@ -118,11 +132,13 @@ def get_equity(tickers, sample="1m",
 
     # List of tickers request
     elif isinstance(tickers, list):
-        compile_tickers = []
-        for tic in tickers:
-            compile_tickers.append(_server_req(
-                str.upper(tic), start_tm, end_tm, equity_freq))
-        return_db = pd.concat(compile_tickers)[columns]
+        processed = []
+        calls = len(tickers)
+        with cf.ThreadPoolExecutor() as pool:
+            for result in pool.map(_server_req, tickers, [start_tm]*calls,
+                                   [end_tm]*calls, [equity_freq]*calls):
+                processed.append(result)
+        return_db = pd.concat(processed)[columns]
         return_db = return_db.set_index(columns[0:2]).unstack(0)
 
     # Unknown ticker request
